# @dcm/commitlint-config

[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/) [![Version](https://img.shields.io/npm/v/@dcm/commitlint-config.svg)](https://npm.im/@dcm/commitlint-config) [![Dependencies](https://img.shields.io/david/dcmhub/commitlint-config.svg)](https://david-dm.org/dcmhub/commitlint-config) [![Dev dependencies](https://img.shields.io/david/dev/dcmhub/commitlint-config.svg)](https://david-dm.org/dcmhub/commitlint-config?type=dev) [![Weekly downloads](https://img.shields.io/npm/dw/@dcm/commitlint-config.svg)](https://npm.im/@dcm/commitlint-config) [![License](https://img.shields.io/npm/l/@dcm/commitlint-config.svg)](https://github.com/dcmhub/commitlint-config/blob/master/LICENSE)

Shareable commitlint and @commitizen config of @dcmhub and @easynm team.

## Installation

Use npx to install peerdeps automatically or install peerDependencies with npm/yarn manually.

```bash
# Install with npx
$ npx install-peerdeps --dev @dcm/commitlint-config

# Install with NPM
$ npm i -D @commitlint/cli @commitlint/prompt commitizen
$ npm i -D @dcm/commitlint-config

# Install with yarn
$ yarn add --dev @commitlint/cli @commitlint/prompt commitizen
$ yarn add --dev @dcm/commitlint-config
```

## Usage

After installation, you have two methods to use this configuration.

### The first method

Create a `commitlint.config.js` or `.commitlintrc.js` file in your project root, then require this package in the file.

```javascript
module.exports = {
  extends: ['@dcm'], // => @dcm/commitlint-config
};
```

You can also overwrite any rules in this configuration.

```javascript
module.exports = {
  extends: ['@dcm'], // => @dcm/commitlint-config
  rules: {
    'header-max-length': [0, 'always', 72],
  },
};
```

### The second method

If your project have a package.json file, add "commitlint" key in your this file.

```json
{
  "name": "my-cool-project-name",
  "version": "1.0.0",
  "commitlint": {
    "extends": ["@dcm"]
  }
}
```

## Use with commitizen

Add a "commit" scripts in the package.json, add `@commitlint/prompt` as commitizen's adapter, now you can use `npm run commit` or `yarn commit` to replace the `git commit` command.

```json
{
  "name": "my-cool-project-name",
  "version": "1.0.0",
  "commitlint": {
    "extends": ["@dcm"]
  },
  "scripts": {
    "commit": "git-cz"
  },
  "config": {
    "commitizen": {
      "path": "@commitlint/prompt"
    }
  }
}
```

## Use with husky

With husky, you can add a `commit-msg` hook to link message before real commit.

```json
{
  "husky": {
    "hooks": {
      "commit-msg": "commitlint -E HUSKY_GIT_PARAMS"
    }
  }
}
```

## License

MIT
